==> aws-cdk.aws-location-1.137.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_location_CfnTrackerConsumerProps(p) {
}
function _aws_cdk_aws_location_CfnRouteCalculatorProps(p) {
}
function _aws_cdk_aws_location_CfnGeofenceCollectionProps(p) {
}
function _aws_cdk_aws_location_CfnTrackerProps(p) {
}
function _aws_cdk_aws_location_CfnMapProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.configuration))
        _aws_cdk_aws_location_CfnMap_MapConfigurationProperty(p.configuration);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_location_CfnPlaceIndexProps(p) {
}
function _aws_cdk_aws_location_CfnGeofenceCollection(p) {
}
function _aws_cdk_aws_location_CfnRouteCalculator(p) {
}
function _aws_cdk_aws_location_CfnTracker(p) {
}
function _aws_cdk_aws_location_CfnTrackerConsumer(p) {
}
function _aws_cdk_aws_location_CfnMap(p) {
}
function _aws_cdk_aws_location_CfnMap_MapConfigurationProperty(p) {
}
function _aws_cdk_aws_location_CfnPlaceIndex(p) {
}
function _aws_cdk_aws_location_CfnPlaceIndex_DataSourceConfigurationProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_location_CfnTrackerConsumerProps, _aws_cdk_aws_location_CfnRouteCalculatorProps, _aws_cdk_aws_location_CfnGeofenceCollectionProps, _aws_cdk_aws_location_CfnTrackerProps, _aws_cdk_aws_location_CfnMapProps, _aws_cdk_aws_location_CfnPlaceIndexProps, _aws_cdk_aws_location_CfnGeofenceCollection, _aws_cdk_aws_location_CfnRouteCalculator, _aws_cdk_aws_location_CfnTracker, _aws_cdk_aws_location_CfnTrackerConsumer, _aws_cdk_aws_location_CfnMap, _aws_cdk_aws_location_CfnMap_MapConfigurationProperty, _aws_cdk_aws_location_CfnPlaceIndex, _aws_cdk_aws_location_CfnPlaceIndex_DataSourceConfigurationProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-location-1.146.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_location_CfnTrackerConsumerProps(p) {
}
function _aws_cdk_aws_location_CfnRouteCalculatorProps(p) {
}
function _aws_cdk_aws_location_CfnGeofenceCollectionProps(p) {
}
function _aws_cdk_aws_location_CfnTrackerProps(p) {
}
function _aws_cdk_aws_location_CfnPlaceIndexProps(p) {
}
function _aws_cdk_aws_location_CfnMapProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.configuration))
        _aws_cdk_aws_location_CfnMap_MapConfigurationProperty(p.configuration);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_location_CfnGeofenceCollection(p) {
}
function _aws_cdk_aws_location_CfnRouteCalculator(p) {
}
function _aws_cdk_aws_location_CfnTracker(p) {
}
function _aws_cdk_aws_location_CfnTrackerConsumer(p) {
}
function _aws_cdk_aws_location_CfnMap(p) {
}
function _aws_cdk_aws_location_CfnMap_MapConfigurationProperty(p) {
}
function _aws_cdk_aws_location_CfnPlaceIndex(p) {
}
function _aws_cdk_aws_location_CfnPlaceIndex_DataSourceConfigurationProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_location_CfnTrackerConsumerProps, _aws_cdk_aws_location_CfnRouteCalculatorProps, _aws_cdk_aws_location_CfnGeofenceCollectionProps, _aws_cdk_aws_location_CfnTrackerProps, _aws_cdk_aws_location_CfnPlaceIndexProps, _aws_cdk_aws_location_CfnMapProps, _aws_cdk_aws_location_CfnGeofenceCollection, _aws_cdk_aws_location_CfnRouteCalculator, _aws_cdk_aws_location_CfnTracker, _aws_cdk_aws_location_CfnTrackerConsumer, _aws_cdk_aws_location_CfnMap, _aws_cdk_aws_location_CfnMap_MapConfigurationProperty, _aws_cdk_aws_location_CfnPlaceIndex, _aws_cdk_aws_location_CfnPlaceIndex_DataSourceConfigurationProperty };
module.exports.DeprecationError = DeprecationError;
